@@ -1,39 +1,24 @@
 /*
-*   Copyright (C) 2010 Dario Freddi <drf@kde.org>
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU Lesser General Public License as published by
-*   the Free Software Foundation; either version 2.1 of the License, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU General Public License for more details.
-*
-*   You should have received a copy of the GNU Lesser General Public License
-*   along with this program; if not, write to the
-*   Free Software Foundation, Inc.,
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
+    SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
+    SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "FakeHelperProxy.h"
 
 namespace KAuth
 {
-
 FakeHelperProxy::FakeHelperProxy()
     : HelperProxy()
 {
-
 }
 
 FakeHelperProxy::~FakeHelperProxy()
 {
-
 }
 
-void FakeHelperProxy::sendProgressStep(const QVariantMap &step)
+void FakeHelperProxy::sendProgressStepData(const QVariantMap &step)
 {
     Q_UNUSED(step)
 }
@@ -77,8 +62,12 @@ void FakeHelperProxy::executeAction(const QString &action, const QString &helper
     Q_UNUSED(details)
     Q_UNUSED(arguments)
     Q_UNUSED(timeout)
-    emit actionPerformed(action, KAuth::ActionReply::NoSuchActionReply());
+    Q_EMIT actionPerformed(action, KAuth::ActionReply::NoSuchActionReply());
+}
+
+int FakeHelperProxy::callerUid() const
+{
+    return -1;
 }
 
 }
-
